==> p5-Alien-wxWidgets-0.62.tgz: libdata/perl5/site_perl/sparc64-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
          'version' => '2.008012',
          'alien_base' => 'gtk2_gcc',
          'compiler' => 'c++',
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include ',
          'linker' => 'c++ -shared -fPIC  ',
          'config' => {
                        'toolkit' => 'gtk2',
                        'unicode' => 0,
                        'debug' => 0,
                        'compiler_kind' => 'gcc',
                        'build' => 'multi',
                        'compiler_version' => '3.4',
                        'mslu' => 0
                      },
          'c_flags' => '-pthread ',
          'prefix' => '/usr/local',
          'link_flags' => '',
          '_libraries' => {
                            'net' => {
                                       'link' => '-lwx_base_net',
                                       'dll' => 'libwx_base_net.so.3.0'
                                     },
                            'aui' => {
                                       'dll' => 'libwx_gtk2_aui.so.3.0',
                                       'link' => '-lwx_gtk2_aui'
                                     },
                            'stc' => {
                                       'dll' => 'libwx_gtk2_stc.so.3.0',
                                       'link' => '-lwx_gtk2_stc'
                                     },
                            'html' => {
                                        'link' => '-lwx_gtk2_html',
                                        'dll' => 'libwx_gtk2_html.so.3.0'
                                      },
                            'core' => {
                                        'link' => '-lwx_gtk2_core',
                                        'dll' => 'libwx_gtk2_core.so.3.0'
                                      },
                            'xrc' => {
                                       'link' => '-lwx_gtk2_xrc',
                                       'dll' => 'libwx_gtk2_xrc.so.3.0'
                                     },
                            'richtext' => {
                                            'dll' => 'libwx_gtk2_richtext.so.3.0',
                                            'link' => '-lwx_gtk2_richtext'
                                          },
                            'qa' => {
                                      'dll' => 'libwx_gtk2_qa.so.3.0',
                                      'link' => '-lwx_gtk2_qa'
                                    },
                            'gizmos' => {
                                          'dll' => 'libwx_gtk2_gizmos.so.3.0',
                                          'link' => '-lwx_gtk2_gizmos'
                                        },
                            'fl' => {
                                      'link' => '-lwx_gtk2_fl',
                                      'dll' => 'libwx_gtk2_fl.so.3.0'
                                    },
                            'xml' => {
                                       'dll' => 'libwx_base_xml.so.3.0',
                                       'link' => '-lwx_base_xml'
                                     },
                            'base' => {
                                        'link' => '-lwx_base',
                                        'dll' => 'libwx_base.so.3.0'
                                      },
                            'gl' => {
                                      'dll' => 'libwx_gtk2_gl.so.3.0',
                                      'link' => '-lwx_gtk2_gl'
                                    },
                            'adv' => {
                                       'dll' => 'libwx_gtk2_adv.so.3.0',
                                       'link' => '-lwx_gtk2_adv'
                                     }
                          },
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc'
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;

==> p5-Alien-wxWidgets-0.67p0.tgz: libdata/perl5/site_perl/sparc64-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          'prefix' => '/usr/local',
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc',
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'link_flags' => '',
          'linker' => 'c++ -shared -fPIC  ',
          'alien_base' => 'gtk2_gcc',
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
          'c_flags' => '-pthread ',
          'config' => {
                        'compiler_version' => '3.4',
                        'unicode' => 0,
                        'build' => 'multi',
                        'debug' => 0,
                        'toolkit' => 'gtk2',
                        'compiler_kind' => 'gcc',
                        'mslu' => 0
                      },
          'version' => '2.008012',
          '_libraries' => {
                            'net' => {
                                       'link' => '-lwx_base_net',
                                       'dll' => 'libwx_base_net.so.3.0'
                                     },
                            'base' => {
                                        'link' => '-lwx_base',
                                        'dll' => 'libwx_base.so.3.0'
                                      },
                            'html' => {
                                        'link' => '-lwx_gtk2_html',
                                        'dll' => 'libwx_gtk2_html.so.3.0'
                                      },
                            'aui' => {
                                       'dll' => 'libwx_gtk2_aui.so.3.0',
                                       'link' => '-lwx_gtk2_aui'
                                     },
                            'xrc' => {
                                       'link' => '-lwx_gtk2_xrc',
                                       'dll' => 'libwx_gtk2_xrc.so.3.0'
                                     },
                            'gl' => {
                                      'link' => '-lwx_gtk2_gl',
                                      'dll' => 'libwx_gtk2_gl.so.3.0'
                                    },
                            'media' => {
                                         'link' => '-lwx_gtk2_media',
                                         'dll' => 'libwx_gtk2_media.so.3.0'
                                       },
                            'gizmos' => {
                                          'link' => '-lwx_gtk2_gizmos',
                                          'dll' => 'libwx_gtk2_gizmos.so.3.0'
                                        },
                            'core' => {
                                        'dll' => 'libwx_gtk2_core.so.3.0',
                                        'link' => '-lwx_gtk2_core'
                                      },
                            'richtext' => {
                                            'link' => '-lwx_gtk2_richtext',
                                            'dll' => 'libwx_gtk2_richtext.so.3.0'
                                          },
                            'xml' => {
                                       'link' => '-lwx_base_xml',
                                       'dll' => 'libwx_base_xml.so.3.0'
                                     },
                            'qa' => {
                                      'dll' => 'libwx_gtk2_qa.so.3.0',
                                      'link' => '-lwx_gtk2_qa'
                                    },
                            'stc' => {
                                       'dll' => 'libwx_gtk2_stc.so.3.0',
                                       'link' => '-lwx_gtk2_stc'
                                     },
                            'adv' => {
                                       'dll' => 'libwx_gtk2_adv.so.3.0',
                                       'link' => '-lwx_gtk2_adv'
                                     },
                            'fl' => {
                                      'dll' => 'libwx_gtk2_fl.so.3.0',
                                      'link' => '-lwx_gtk2_fl'
                                    }
                          },
          'compiler' => 'c++',
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include -I/usr/X11R6/include '
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;
